Module: Warpaint

Defined in:
lib/warpaint.rb,
lib/warpaint/cli.rb,
lib/warpaint/gpx.rb,
lib/warpaint/netxml.rb,
lib/warpaint/parser.rb,
lib/warpaint/version.rb,
lib/warpaint/renderer.rb,
lib/warpaint/point_collection.rb,
lib/warpaint/network_collection.rb,
lib/warpaint/ordered_collection.rb

Overview

  • CLI handles the parsing of the command line.
  • Parser provides generic parer functionality.
  • NetXML handles the parsing of the Kismet NetXML.
  • GPX handles the parsing of the GPS Exchange Format.
  • NetworkCollection provides a data structure for storing information about detected networks.
  • PointCollection provides a data structure for storing GPS data.
  • Renderer handles the rendering of the Google Earth KML file.

Defined Under Namespace

Classes: CLI, GPX, NetXML, NetworkCollection, OrderedCollection, Parser, PointCollection, Renderer

Constant Summary collapse

VERSION =
"0.0.1"